/*************************************************************************
 * typedefs.h - 
 *
 * $Id: typedefs.h,v 1.1 2005/12/02 22:22:15 ziad Exp $
 *
 * CopyrightINRIA 1998
 *
 * AUTHOR:
 * Gregoire Malandain (greg@sophia.inria.fr)
 * http://www.inria.fr/epidaure/personnel/malandain/
 * 
 * CREATION DATE: 
 * June, 9 1998
 *
 *
 *
 */

#ifndef _typedefs_h_
#define _typedefs_h_

#ifdef __cplusplus
extern "C" {
#endif





/* Differents type coding for images and buffers.
 */
typedef enum {
  TYPE_UNKNOWN /* unknown type */,
  UCHAR  /* unsigned char */,
  SCHAR  /* signed char */,
  USHORT /* unsigned short int */,
  SSHORT /* signed short int */,
  INT    /* signed int */,
  ULINT  /* unsigned long int */,
  FLOAT  /* float */,
  DOUBLE  /* double */
} ImageType, bufferType;

typedef char               s8;
typedef unsigned char      u8;
typedef short int          s16;
typedef unsigned short int u16;
typedef int                i32;
typedef int                s32;
typedef unsigned long int  u64;
typedef float              r32;
typedef double             r64;




#if 0
/* Typedef Booleen (False causes a parse error when compiling from AFNI)
   These do not appear used
 */
typedef enum {
  False = 0,
  True = 1
} typeBoolean;
#endif

#ifdef __cplusplus
}
#endif

#endif
